==> node-steam-bot-manager-1.0.46.tgz: package/README.md <==
# About
A bot management tool for [Steam Community](http://www.steamcommunity.com) built using NodeJS backend.



Version 1.0.46

[![forthebadge](http://forthebadge.com/images/badges/uses-js.svg)](http://forthebadge.com)
[![forthebadge](http://forthebadge.com/images/badges/built-with-love.svg)](http://forthebadge.com)

## Demo:
##### No demo's currently exist. If you would like a quick demo, please contact Undeadkillz on Steam.

To showcase a demo of your use, pm Undeadkillz on Steam or Github with your website using this bot.



## Examples:
You can check examples of bots you can build by navigating to the 'examples' folder in the root of the project.

## Features:
- GUI-based control
- GUI-Messaging
- GUI-Trading
- 2-Factor Authentication Support + Enabling
- Enable API-Key 
- Manage multiple bots simultaneously
- API Support for third-party systems (Betting, Trading, and so on..)
- Even based interactions of a single bot or multiple
- Ability to upvote/downvote attachments on Steam Community


## TODO:
- Add more functionality
- Expand API access
- Add more examples

Visit the [wiki](https://github.com/Undeadkillz/node-steam-bot-manager/wiki) for set-up, registration and docs.

## Libraries used:
- [colors.js](https://github.com/marak/colors.js/)
- [node-steamstore](https://github.com/DoctorMcKay/node-steamstore)
- [node-steam-totp](https://github.com/DoctorMcKay/node-steam-totp)
- [node-steam-tradeoffer-manager](https://github.com/DoctorMcKay/node-steam-tradeoffer-manager)
- [node-steamcommunity](https://github.com/DoctorMcKay/node-steamcommunity)

## How to contribute:
~~~
git clone https://github.com/Undeadkillz/node-steam-bot-manager # Clone project files locally
node install # To install the tool and dependancies
~~~
The project is still in early stages, and any feedback or contribution is appreciated.

#### To contribute:
Simply make your desired changes and submit your pull request. At this point, there is no specific format you have to follow, just make sure the code is easily readable, and if possible comment where possible so that the pull request could be approved faster.

#### To help:
Install the tool, and try out the different examples or even build your own, and try to break the tool. Once you break it, just make sure to inform us via the ISSUES pages, about the issue.

Make sure to atleast include a log of the error message and if possible inform us about the steps to reproduce the issue.

## Testing Policy
[![forthebadge](http://forthebadge.com/images/badges/fuck-it-ship-it.svg)](http://forthebadge.com)

I will ensure everything works, however I won't be building any unit-tests at this time.

---


## Credits:
- [Undeadkillz](https://github.com/Undeadkillz) | Add me on: **[Steam](http://steamcommunity.com/profiles/76561198042954517/)**
- All authors and helpers of the libraries listed above (with their respective library urls)

[![forthebadge](http://forthebadge.com/images/badges/powered-by-water.svg)](http://forthebadge.com)
[![forthebadge](http://forthebadge.com/images/badges/gluten-free.svg)](http://forthebadge.com)

\* Using this feature means you agree to Steam's API terms found at: [Steam API Terms](http://steamcommunity.com/dev/apiterms)

==> node-steam-bot-manager-1.0.47.tgz: package/README.md <==
# About
A bot management tool for [Steam Community](http://www.steamcommunity.com) built with NodeJS. Allows users to customize bot actions to the needs of their websites. Whether you are looking for bots to message users when an in-game report occurs, or invite users to your group when they join your server, this tool offers a powerful & easy API.



[![npm version](https://badge.fury.io/js/node-steam-bot-manager.svg)](https://badge.fury.io/js/node-steam-bot-manager)



[![forthebadge](http://forthebadge.com/images/badges/uses-js.svg)](http://forthebadge.com)
[![forthebadge](http://forthebadge.com/images/badges/built-with-love.svg)](http://forthebadge.com)

## Features:
- GUI-Based Bot Control
- GUI-Based Messaging
- GUI-Based Trading
- 2-Factor Authentication Support + Setup
- Enable API-Key*
- Generate authentication codes on demand (for manual login)
- Manage multiple bots simultaneously
- Login using email/2-factor authentication
- API Support for third-party systems (Betting, Trading, and so on..)
- Event based interactions of a single bot or multiple
- Ability to upvote/downvote attachments on Steam Community
- Ability to import accounts into tool 

## WIKI
#### Visit the [wiki](https://github.com/Undeadkillz/node-steam-bot-manager/wiki) for set-up, registration.

#### For Docs, please visit [our docs](http://undeadkillz.github.io/node-steam-bot-manager/docs)
 If you need further help with setting up the tool, please contact me on Steam, and I will try my best to help you.

## Examples:
You can check examples of bots you can build by navigating to the 'examples' folder in the root of the project.


## TODO:
- Expand API access
- Add more examples


## Libraries used:
- [node-steamstore](https://github.com/DoctorMcKay/node-steamstore)
- [node-steam-totp](https://github.com/DoctorMcKay/node-steam-totp)
- [node-steam-tradeoffer-manager](https://github.com/DoctorMcKay/node-steam-tradeoffer-manager)
- [node-steamcommunity](https://github.com/DoctorMcKay/node-steamcommunity)
- Glob
- Jasmine
- jsdocs
- Winston
- Request
- Express
## How to contribute:
~~~
git clone https://github.com/Undeadkillz/node-steam-bot-manager # Clone project files locally
node install # To install the tool and dependancies
~~~
The project is still in early stages, and any feedback or contribution is appreciated.

#### To contribute:
Simply make your desired changes and submit your pull request. At this point, there is no specific format you have to follow, just make sure the code is easily readable, and if possible comment where possible so that the pull request could be approved faster.

#### To help:
Install the tool, and try out the different examples or even build your own, and try to break the tool. Once you break it, just make sure to inform us via the ISSUES pages, about the issue.

Make sure to atleast include a log of the error message and if possible inform us about the steps to reproduce the issue.

## Testing Policy
[![forthebadge](http://forthebadge.com/images/badges/fuck-it-ship-it.svg)](http://forthebadge.com)

I will ensure everything works, however I won't be building any unit-tests at this time.

---
Stable versions via npm (incase your version contains certain bugs, try these builds):
- 1.0.46

#### Git Version
Frequently the Github source will not be the same version as the latest npm version. This is because the npm versions are often the stable ones. Github will contain the developmental and possibly even broken versions at times (official versions will be stated in the commit)

## Credits:
- [Undeadkillz](https://github.com/Undeadkillz) | Add me on: **[Steam](http://steamcommunity.com/profiles/76561198042954517/)**
- All authors and helpers of the libraries listed above (with their respective library urls)

[![forthebadge](http://forthebadge.com/images/badges/powered-by-water.svg)](http://forthebadge.com)
[![forthebadge](http://forthebadge.com/images/badges/gluten-free.svg)](http://forthebadge.com)

\* Using this feature means you agree to Steam's API terms found at: [Steam API Terms](http://steamcommunity.com/dev/apiterms)
